summaryrefslogtreecommitdiff
path: root/sapi/nsapi
diff options
context:
space:
mode:
authorUwe Schindler <thetaphi@php.net>2003-07-15 17:30:33 +0000
committerUwe Schindler <thetaphi@php.net>2003-07-15 17:30:33 +0000
commite3a55ba2975d742fda74a14be4fd73c975f14cb0 (patch)
treeb5cf2e5ab0b2057e55c873391c2d68d91ef08631 /sapi/nsapi
parentb0a4e1a2d263137d53589eb1f1f0f6d4bb118a7a (diff)
downloadphp-git-e3a55ba2975d742fda74a14be4fd73c975f14cb0.tar.gz
Make virtual() an alias for nsapi_virtual() -- better for docs/naming in future
Diffstat (limited to 'sapi/nsapi')
-rw-r--r--sapi/nsapi/nsapi.c15
1 files changed, 8 insertions, 7 deletions
diff --git a/sapi/nsapi/nsapi.c b/sapi/nsapi/nsapi.c
index f69bb4bc71..4ebe98df70 100644
--- a/sapi/nsapi/nsapi.c
+++ b/sapi/nsapi/nsapi.c
@@ -160,7 +160,7 @@ PHP_RINIT_FUNCTION(nsapi);
PHP_RSHUTDOWN_FUNCTION(nsapi);
PHP_MINFO_FUNCTION(nsapi);
-PHP_FUNCTION(virtual);
+PHP_FUNCTION(nsapi_virtual);
PHP_FUNCTION(nsapi_request_headers);
PHP_FUNCTION(nsapi_response_headers);
@@ -177,7 +177,8 @@ ZEND_DECLARE_MODULE_GLOBALS(nsapi)
* Every user visible function must have an entry in nsapi_functions[].
*/
function_entry nsapi_functions[] = {
- PHP_FE(virtual, NULL) /* Make subrequest */
+ PHP_FE(nsapi_virtual, NULL) /* Make subrequest */
+ PHP_FALIAS(virtual, nsapi_virtual, NULL) /* compatibility */
PHP_FE(nsapi_request_headers, NULL) /* get request headers */
PHP_FALIAS(getallheaders, nsapi_request_headers, NULL) /* compatibility */
PHP_FALIAS(apache_request_headers, nsapi_request_headers, NULL) /* compatibility */
@@ -301,7 +302,7 @@ PHP_MINFO_FUNCTION(nsapi)
php_info_print_table_start();
php_info_print_table_row(2, "NSAPI Module Version", nsapi_module_entry.version);
php_info_print_table_row(2, "Server Software", system_version());
- php_info_print_table_row(2, "Sub-requests with virtual()",
+ php_info_print_table_row(2, "Sub-requests with nsapi_virtual()",
(nsapi_servact_service)?((zend_ini_long("zlib.output_compression", sizeof("zlib.output_compression"), 0))?"not supported with zlib.output_compression":"enabled"):"not supported on this platform" );
php_info_print_table_end();
@@ -309,14 +310,14 @@ PHP_MINFO_FUNCTION(nsapi)
}
/* }}} */
-/* {{{ proto bool virtual(string filename)
+/* {{{ proto bool nsapi_virtual(string uri)
Perform an NSAPI sub-request */
/* This function is equivalent to <!--#include virtual...-->
* in SSI. It does an NSAPI sub-request. It is useful
* for including CGI scripts or .shtml files, or anything else
* that you'd parse through webserver.
*/
-PHP_FUNCTION(virtual)
+PHP_FUNCTION(nsapi_virtual)
{
pval **uri;
int rv;
@@ -822,11 +823,11 @@ int NSAPI_PUBLIC php5_execute(pblock *pb, Session *sn, Request *rq)
TSRMLS_FETCH();
/* check if this uri was included in an other PHP script with virtual()
by looking for a request context in the current thread */
if (SG(server_context)) {
/* send 500 internal server error */
- log_error(LOG_WARN, "php5_execute", sn, rq, "Cannot make nesting PHP requests with virtual()");
+ log_error(LOG_WARN, "php5_execute", sn, rq, "Cannot make nesting PHP requests with nsapi_virtual()");
protocol_status(sn, rq, 500, NULL);
return REQ_ABORTED;
}
@@ -822,11 +823,11 @@ int NSAPI_PUBLIC php5_execute(pblock *pb, Session *sn, Request *rq)
TSRMLS_FETCH();
- /* check if this uri was included in an other PHP script with virtual()
+ /* check if this uri was included in an other PHP script with nsapi_virtual()
by looking for a request context in the current thread */
if (SG(server_context)) {